@@ -107,6 +107,14 @@ Example (in C<debian/control>):
                     labix.org/v2/mgo,
                     launchpad.net/mgo
 
+C<DH_GOPKG> is set by dh-golang, and as a consequence it is not present in the
+C<debian/rules> environment. If you need to use the Go package name in the
+C<debian/rules> file, you must define it yourself.
+
+Example (in C<debian/rules>):
+
+ export DH_GOPKG := github.com/go-mgo/mgo
+
 Historical note: before the C<XS-Go-Import-Path> field was introduced, we used
 to set C<DH_GOPKG> in C<debian/rules>. When you encounter such a package, please
 convert it by moving the value from C<debian/rules> to C<debian/control>. It is
@@ -268,12 +276,6 @@ sub _set_gocache {
     $ENV{GOCACHE} = "off";
 }
 
-sub _go1_has_minor {
-    my ($_go1_minor) = (qx(go version) =~ /go version go1\.([0-9]+)/);
-    my ($minor) = @_;
-    return $_go1_minor >= $minor;
-}
-
 sub _link_contents {
     my ($src, $dst) = @_;
 
@@ -438,20 +440,8 @@ sub build {
         $this->doit_in_builddir("go", "generate", "-v", @_, get_targets());
     }
     unshift @_, ('-p', $this->get_parallel());
-
-    my @targets = $this->get_targets();
-
-    if (_go1_has_minor(13)) {
-        # Go 1.13 officially supports reproducible build, adding new -trimpath option
-        # https://github.com/golang/go/issues/16860
-        $this->doit_in_builddir("go", "install", "-trimpath", "-v", @_, @targets);
-    } elsif (_go1_has_minor(10)) {
-        # Go 1.10 changed flag behaviour, -{gc,asm}flags=all= only works for Go >= 1.10.
-        my $trimpath = "all=\"-trimpath=" . $ENV{GOPATH} . "/src\"";
-        $this->doit_in_builddir("go", "install", "-gcflags=$trimpath", "-asmflags=$trimpath", "-v", @_, @targets);
-    } else {
-        $this->doit_in_builddir("go", "install", "-v", @_, @targets);
-    }
+    my $trimpath = "\"-trimpath=" . $ENV{GOPATH} . "/src\"";
+    $this->doit_in_builddir("go", "install", "-gcflags=$trimpath", "-asmflags=$trimpath", "-v", @_, get_targets());
 }
 
 sub test {
